@@ -6,9 +6,8 @@ use base 'Parse::AFP::Record';
 
 use constant SUBFORMAT => (
     EscapeSequence => 'H4',	# 2BD3
-    MemberData => ['C/a* X', '*'],
+    'PTX::ControlSequence' => ['C/a* X', '*'],
 );
-use constant MEMBER_CLASS => 'PTX::ControlSequence';
 
 sub refresh {
     my ($self) = @_;
@@ -33,7 +32,7 @@ sub load_struct {
     # XXX - first get the header, then split with 2BD3,
     # then do a step-by-step tokenization to make sure
     # raw text fields get respected
-    $self->{Struct} = $self->parser->unformat($$data . $self->padding);
+    $self->set_struct( $self->parser->unformat($$data . $self->padding) );
 }
 
 1;
